<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2005 m3 Media Services Limited                         |
| For contact details, see: http://www.m3.net/                              |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: adframe.plugin.php 3312 2005-06-09 11:41:05Z andrew $
*/

/**
 * @package    Plugins
 * @subpackage InvocationTags
 * @author     Radek Maciaszek <radek@m3.net>
 *
 */

require_once MAX_PATH . '/plugins/invocationTags/InvocationTags.php';
require_once MAX_PATH . '/lib/max/Plugins/PluginTranslation.php';

/**
 *
 * Invocation tag plugin.
 *
 */
class Plugins_InvocationTags_adframe_adframe extends Plugins_InvocationTags 
{
    
    /**
     * Return name of plugin
     *
     * @return string
     */
    function getName()
    {
        return Max_PluginTranslation::translate('Remote Invocation for Frames', $this->module, $this->package);
    }
    
    /**
     * Return preference code
     *
     * @return string
     */
    function getPreferenceCode()
    {
        return 'allow_invocation_frame';
    }
    
    /**
     * Check if plugin is allowed
     *
     * @return boolean  True - allowed, false - not allowed
     */
    function isAllowed($extra)
    {
        $isAllowed = parent::isAllowed($extra);
        if((is_array($extra) && $this->maxInvocation->server_same == false && 
               ($extra['width'] == '-1' || $extra['height'] == '-1'))
               || (is_array($extra) && $extra['delivery'] == phpAds_ZoneText)) {
            return false;
        } else {
            return $isAllowed;
        }
    }
    
    /**
     * Return list of options
     *
     * @return array    Group of options
     */
    function getOptionsList()
    {
        $options = array (
            'spacer'      => MAX_PLUGINS_INVOCATION_TAGS_STANDARD,
            'what'        => MAX_PLUGINS_INVOCATION_TAGS_STANDARD,
            //'clientid'    => MAX_PLUGINS_INVOCATION_TAGS_STANDARD,
            'campaignid'  => MAX_PLUGINS_INVOCATION_TAGS_STANDARD,
            'target'      => MAX_PLUGINS_INVOCATION_TAGS_STANDARD,
            'source'      => MAX_PLUGINS_INVOCATION_TAGS_STANDARD,
            'refresh'     => MAX_PLUGINS_INVOCATION_TAGS_STANDARD,
            'size'        => MAX_PLUGINS_INVOCATION_TAGS_STANDARD,
            'resize'      => MAX_PLUGINS_INVOCATION_TAGS_STANDARD,
            'transparent' => MAX_PLUGINS_INVOCATION_TAGS_STANDARD,
            'ilayer'      => MAX_PLUGINS_INVOCATION_TAGS_STANDARD
        );
        
        return $options;
    }    

    /**
     * Return invocation code for this plugin (codetype)
     *
     * @return string
     */
    function generateInvocationCode()
    {
        parent::prepareCommonInvocationData();
        
        $conf = $GLOBALS['_MAX']['CONF'];
        $mi = &$this->maxInvocation;
        
        $buffer  = '<!-- Max Media Manager Remote iframes Tag' . "\n";
        $buffer .= '  --' . "\n";
        $buffer .= '  -- Generated with Max ' . MAX_VERSION_READABLE . "\n";
        $buffer .= '  --' . "\n";
        // Support for 3rd party server clicktracking
        if (isset($mi->thirdpartytrack) && $mi->thirdpartytrack == '1') {
            $buffer .= '  -- Don\'t forget to replace the \'Insert_Clicktrack_URL_Here\' text with' . "\n";
            $buffer .= '  -- the click tracking URL if this ad is to be delivered through a 3rd' . "\n";
            $buffer .= '  -- party (non-Max) ad server.' . "\n";
            $buffer .= '  --' . "\n";
            $buffer .= '  -- Don\'t forget to replace the \'Insert_Random_Number_Here\' text with' . "\n";
            $buffer .= '  -- a cache-buster random number each time you deliver the tag through' . "\n";
            $buffer .= '  -- a 3rd party (non-Max) ad server.' . "\n";
            $buffer .= '  --' . "\n";
        }
        $buffer .= '  -- This tag has been generated for use on a non-SSL page. If this tag' . "\n";
        $buffer .= '  -- is to be placed on an SSL page, change all instances of' . "\n";
        $buffer .= '  --   \'http://'.$conf['webpath']['delivery'].'/...\'' . "\n";
        $buffer .= '  -- to' . "\n";
        $buffer .= '  --   \'https://'.$conf['webpath']['deliverySSL'].'/...\'' . "\n";
        $buffer .= '  --' . "\n";
        $buffer .= '  -- If iframes are not supported by the viewer\'s browser, then this' . "\n";
        $buffer .= '  -- tag only shows image banners. There is no width or height in these' . "\n";
        $buffer .= '  -- banners, so if you want these tags to allocate space for the ad' . "\n";
        $buffer .= '  -- before it shows, you will need to add this information to the <img>' . "\n";
        $buffer .= '  -- tag.' . "\n";
        $buffer .= '  -->' . "\n\n";
        if (isset($mi->refresh) && $mi->refresh != '') {
            $mi->parameters['refresh'] = "refresh=".$mi->refresh;
        }
        if (isset($mi->resize) && $mi->resize == '1') {
            $mi->parameters['resize'] = "resize=1";
        }
        if (isset($mi->thirdpartytrack) && $mi->thirdpartytrack == '1') {
           $mi->parameters['cb'] = "cb=Insert_Random_Number_Here";
           $mi->parameters['ct0'] = "ct0=Insert_Clicktrack_URL_Here";
        }
        $buffer .= "<iframe id='".$mi->uniqueid."' name='".$mi->uniqueid."' src='".constructDeliveryURL($conf['file']['frame']);
        $buffer .= "?n=".$mi->uniqueid;
        if (sizeof($mi->parameters) > 0) {
            $buffer .= "&".implode ("&", $mi->parameters);
        }
        $buffer .= "' framespacing='0' frameborder='no' scrolling='no'";
        if (isset($mi->width) && $mi->width != '' && $mi->width != '-1') {
            $buffer .= " width='".$mi->width."'";
        }
        if (isset($mi->height) && $mi->height != '' && $mi->height != '-1') {
            $buffer .= " height='".$mi->height."'";
        }
        if (isset($mi->transparent) && $mi->transparent == '1') {
            $buffer .= " allowtransparency='true'";
        }
        $buffer .= ">";
        if (isset($mi->refresh) && $mi->refresh != '') {
            unset ($mi->parameters['refresh']);
        }
        if (isset($mi->resize) && $mi->resize == '1') {
            unset ($mi->parameters['resize']);
        }
        if (isset($mi->uniqueid) && $mi->uniqueid != '') {
            $mi->parameters['n'] = "n=".$mi->uniqueid;    
        }
        if (isset($mi->parameters['target'])) {
            unset ($mi->parameters['target']);
        }
        if (isset($mi->ilayer) && $mi->ilayer == 1 &&  isset($mi->width) && $mi->width != '' && $mi->width != '-1' && isset($mi->height) && $mi->height != '' && $mi->height != '-1') {
            $buffer .= "<script language='JavaScript' type='text/javascript'>\n";
            $buffer .= "<!--\n";
            $buffer .= "   document.write (\"<nolayer>\");\n";
            $buffer .= "   document.write (\"<a href='".constructDeliveryURL($conf['file']['click']);
            $buffer .= "?n=".$mi->uniqueid;
            $buffer .= "'";
            if (isset($mi->target) && $mi->target != '') {
                $buffer .= " target='".$mi->target."'";
            } else {
                $buffer .= " target='_blank'";
            }
            $buffer .= ">\n<img src='".constructDeliveryURL($conf['file']['view']);
            if (sizeof($mi->parameters) > 0) {
                $buffer .= "?".implode ("&", $mi->parameters);
            }
            $buffer .= "' border='0' alt='' /></a>\");\n";
            $buffer .= "   document.write (\"</nolayer>\");\n";
            $buffer .= "   document.write (\"<ilayer id='layer".$mi->uniqueid."' visibility='hidden' width='".$mi->width."' height='".$mi->height."'></ilayer>\");\n";
            $buffer .= "//-->\n";
            $buffer .= "</script>";
            $buffer .= "<noscript>\n  <a href='".constructDeliveryURL($conf['file']['click']);
            $buffer .= "?n=".$mi->uniqueid;
            $buffer .= "'";
            if (isset($mi->target) && $mi->target != '') {
                $buffer .= " target='$mi->target'";
            }
            $buffer .= ">\n  <img src='".constructDeliveryURL($conf['file']['view']);
            if (sizeof($mi->parameters) > 0) {
                $buffer .= "?".implode ("&", $mi->parameters);
            }
            $buffer .= "' border='0' alt='' /></a></noscript>";
        } else {
            $buffer .= "<a href='".constructDeliveryURL($conf['file']['click']);
            $buffer .= "?n=".$mi->uniqueid;
            // Support for 3rd party server clicktracking
            if (isset($mi->thirdpartytrack) && $mi->thirdpartytrack == '1') {
                $buffer .= "&ct0=Insert_Clicktrack_URL_Here";
            }
            $buffer .= "'";
            if (isset($mi->target) && $mi->target != '') {
                $buffer .= " target='".$mi->target."'";
            } else {
                $buffer .= " target='_blank'";
            }
            $buffer .= "><img src='".constructDeliveryURL($conf['file']['view']);
            if (sizeof($mi->parameters) > 0) {
                $buffer .= "?";
                foreach ($mi->parameters as $thisKey => $thisValue) {
                    if ($thisKey != "ct0") {
                        $buffer .= "&".$thisValue;
                    }
                }
            }
            $buffer .= "' border='0' alt='' /></a>";
        }
        $buffer .= "</iframe>\n";
        if (isset($mi->parameters['n'])) {
            unset ($mi->parameters['n']);
        }
        if (isset($mi->target) && $mi->target != '') {
            $mi->parameters['target'] = "target=".urlencode($mi->target);
        }
        if (isset($mi->ilayer) && $mi->ilayer == 1 && isset($mi->width) && $mi->width != '' && $mi->width != '-1' && isset($mi->height) && $mi->height != '' && $mi->height != '-1') {
            // Do no rewrite target frames
            $mi->parameters['rewrite'] = 'rewrite=0';
            $buffer .= "\n\n";
            $buffer .= "<!-- Place this part of the code just above the </body> tag -->\n";
            $buffer .= "<layer src='".constructDeliveryURL($conf['file']['frame']);
            $buffer .= "?n=".$mi->uniqueid;
            if (sizeof($mi->parameters) > 0) {
                $buffer .= "&".implode ("&", $mi->parameters);
            }
            $buffer .= "' width='".$mi->width."' height='".$mi->height."' visibility='hidden' onLoad=\"moveToAbsolute(layer".$mi->uniqueid.".pageX,layer".$mi->uniqueid.".pageY);clip.width=".$mi->width.";clip.height=".$mi->height.";visibility='show';\"></layer>";
        }
        
        return $buffer;
    }

}

?>