<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2005 m3 Media Services Limited                         |
| For contact details, see: http://www.m3.net/                              |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: trackerhistory.plugin.php 3655 2005-09-09 15:52:24Z radek $
*/

/**
 * @package    MaxPlugins
 * @subpackage Reports
 * @author     Misza Pawlowski <michal@m3.net>
 * @author     Radek Maciaszek <radek@m3.net>
 */

require_once MAX_PATH . '/plugins/reports/Reports.php';

class Plugins_Reports_Advertiser_Trackerhistory extends Plugins_Reports {
    
    
    // Public info function
    function info()
    {
        global $strCampaignHistory, $strClient, $strCampaign, $strPluginTrackerHistory, $strDelimiter, $strStartDate, $strEndDate;
    
        include_once MAX_PATH . '/lib/max/Plugins/PluginTranslation.php';
        Max_PluginTranslation::init($this->module, $this->package);
        
        $plugininfo = array (
    		"plugin-name"			=> Max_PluginTranslation::translate('Tracking Report', $this->module, $this->package),
    		"plugin-description"	=> Max_PluginTranslation::translate('A detailed breakdown of conversion tracking.', $this->module, $this->package),
    		'plugin-category'     => 'advertiser',
    		'plugin-category-name'	=> Max_PluginTranslation::translate('Advertiser Reports', $this->module, $this->package),
            'plugin-author'         => 'Andrew Hill',
            'plugin-export'         => "csv",
            'plugin-authorize'      => phpAds_Admin+phpAds_Agency,
            'plugin-import'         => array (
                    'clientid'    => array (
                            'title'    => $strClient,
                            'type'     => 'clientid-dropdown'
                    ),
                    'start'       => array (
                            'title'    => $strStartDate,
                            'type'      => 'edit',
                            'size'      => 10,
                            'default'   => date('Y/m/d', mktime(0, 0, 0, date('m'), date('d')-7, date('Y')))
                    ),
                    'end'       => array (
                            'title'     => $strEndDate,
                            'type'      => 'edit',
                            'size'      => 10,
                            'default'   => date('Y/m/d', mktime(0, 0, 0, date('m'), date('d')-1, date('Y')))
                    ),
                    'delimiter' => array (
                            'title'     => $strDelimiter,
                            'type'      => 'edit',
                            'size'      => 1,
                            'default'   => ','
                    )
                )
            );
    
        return $plugininfo;
    }
    
    /*-------------------------------------------------------*/
    /* Private plugin function                               */
    /*-------------------------------------------------------*/
    
    function execute($clientid, $start, $end, $delimiter=',')
    {   
        $conf = & $GLOBALS['_MAX']['CONF'];
        
        global $date_format;
        global $strCampaign, $strTotal, $strDay, $strImpressions, $strClicks, $strCTRShort;
    
        // Create Date objects of the start and end dates
        require_once 'Date.php';
        $start = date('Y-m-d', strtotime($start));
        $end   = date('Y-m-d', strtotime($end));
        $startDate = new Date($start . '00:00:00');
        $endDate   = new Date($end   . '23:59:59');
    
        // How many days does the report span?
        $days = Date_Calc::dateDiff($startDate->getDay(), $startDate->getMonth(), $startDate->getYear(),
                                    $endDate->getDay(),   $endDate->getMonth(),   $endDate->getYear());
        
        // Prepare the report data array
        $trackers = array();
        
        // Get all trackers for the client
        $query = "
            SELECT
                trackerid AS tracker_id, 
                trackername AS tracker_name
            FROM
                {$conf['table']['prefix']}{$conf['table']['trackers']}
            WHERE
                clientid = $clientid
            ";
        $resTrackers = phpAds_dbQuery($query);
        while ($row = phpAds_dbFetchArray($resTrackers)) {
            $trackers[$row['tracker_id']]                = array();
            $trackers[$row['tracker_id']]['name']        = $row['tracker_name'];
            // Also set the total tracker impressions, connections, and conversions to zero
            $trackers[$row['tracker_id']]['total_tracker_impressions'] = 0;
            $trackers[$row['tracker_id']]['total_tracker_connections'] = 0;
            $trackers[$row['tracker_id']]['total_tracker_conversions'] = 0;
        }
    
        // Get the tracker impressions for each tracker, for each day of the report
        $currentDate = $startDate;
        for ($counter = 0; $counter <= $days; $counter++) {
            // Get the current date's tracker impressions
            $query = "
                SELECT
                    t.trackerid AS tracker_id,
                    COUNT(*) AS impressions
                FROM
                    {$conf['table']['prefix']}{$conf['table']['trackers']} AS t,
                    {$conf['table']['prefix']}{$conf['table']['data_intermediate_ad_connection']} AS diac
                WHERE
                    t.clientid = $clientid
                    AND t.trackerid = diac.tracker_id
                    AND diac.tracker_date_time >= '" . $currentDate->format('%Y-%m-%d 00:00:00') . "'
                    AND diac.tracker_date_time <= '" . $currentDate->format('%Y-%m-%d 23:59:59') . "'
                GROUP BY
                    tracker_id
                ";
            $resTrackerImpressions = phpAds_dbQuery($query);
            while ($row = phpAds_dbFetchArray($resTrackerImpressions)) {
                $trackers[$row['tracker_id']][$currentDate->format('%Y-%m-%d').'_tracker_impressions'] = $row['impressions'];
                $trackers[$row['tracker_id']]['total_tracker_impressions'] += $row['impressions'];
            }
            // Update the current date
            $currentDate = $currentDate->getNextDay();
        }
        
        // Get the tracker connections for each tracker, for each day of the report
        $currentDate = $startDate;
        for ($counter = 0; $counter <= $days; $counter++) {
            $query = "
                SELECT
                    t.trackerid AS tracker_id,
                    COUNT(*) AS connections
                FROM
                    {$conf['table']['prefix']}{$conf['table']['trackers']} AS t,
                    {$conf['table']['prefix']}{$conf['table']['data_intermediate_ad_connection']} AS diac
                WHERE
                    t.clientid = $clientid
                    AND t.trackerid = diac.tracker_id
                    AND diac.tracker_date_time >= '" . $currentDate->format('%Y-%m-%d 00:00:00') . "'
                    AND diac.tracker_date_time <= '" . $currentDate->format('%Y-%m-%d 23:59:59') . "'
                    AND diac.connection_type = 0
                GROUP BY
                    tracker_id
                ";
            $resTrackerConnections = phpAds_dbQuery($query);
            while ($row = phpAds_dbFetchArray($resTrackerConnections)) {
                $trackers[$row['tracker_id']][$currentDate->format('%Y-%m-%d').'_tracker_impression_connections'] = $row['connections'];
                $trackers[$row['tracker_id']]['total_tracker_connections'] += $row['connections'];
            }
            // Update the current date
            $currentDate = $currentDate->getNextDay();
        }
        $currentDate = $startDate;
        for ($counter = 0; $counter <= $days; $counter++) {
            $query = "
                SELECT
                    t.trackerid AS tracker_id,
                    COUNT(*) AS connections
                FROM
                    {$conf['table']['prefix']}{$conf['table']['trackers']} AS t,
                    {$conf['table']['prefix']}{$conf['table']['data_intermediate_ad_connection']} AS diac
                WHERE
                    t.clientid = $clientid
                    AND t.trackerid = diac.tracker_id
                    AND diac.tracker_date_time >= '" . $currentDate->format('%Y-%m-%d 00:00:00') . "'
                    AND diac.tracker_date_time <= '" . $currentDate->format('%Y-%m-%d 23:59:59') . "'
                    AND diac.connection_type = 1
                GROUP BY
                    tracker_id
                ";
            $resTrackerConnections = phpAds_dbQuery($query);
            while ($row = phpAds_dbFetchArray($resTrackerConnections)) {
                $trackers[$row['tracker_id']][$currentDate->format('%Y-%m-%d').'_tracker_click_connections'] = $row['connections'];
                $trackers[$row['tracker_id']]['total_tracker_connections'] += $row['connections'];
            }
            // Update the current date
            $currentDate = $currentDate->getNextDay();
        }
        
        // Get the tracker conversions for each tracker, for each day of the report
        $currentDate = $startDate;
        for ($counter = 0; $counter <= $days; $counter++) {
            $query = "
                SELECT
                    t.trackerid AS tracker_id,
                    COUNT(*) AS conversions
                FROM
                    {$conf['table']['prefix']}{$conf['table']['trackers']} AS t,
                    {$conf['table']['prefix']}{$conf['table']['data_intermediate_ad_connection']} AS diac
                WHERE
                    t.clientid = $clientid
                    AND t.trackerid = diac.tracker_id
                    AND diac.tracker_date_time >= '" . $currentDate->format('%Y-%m-%d 00:00:00') . "'
                    AND diac.tracker_date_time <= '" . $currentDate->format('%Y-%m-%d 23:59:59') . "'
                    AND diac.connection_type = 0
                    AND diac.connection_status = ". MAX_CONNECTION_STATUS_APPROVED ."
                GROUP BY
                    tracker_id
                ";
            $resTrackerConnections = phpAds_dbQuery($query);
            while ($row = phpAds_dbFetchArray($resTrackerConnections)) {
                $trackers[$row['tracker_id']][$currentDate->format('%Y-%m-%d').'_tracker_impression_conversions'] = $row['conversions'];
                $trackers[$row['tracker_id']]['total_tracker_conversions'] += $row['conversions'];
            }
            // Update the current date
            $currentDate = $currentDate->getNextDay();
        }
        $currentDate = $startDate;
        for ($counter = 0; $counter <= $days; $counter++) {
            $query = "
                SELECT
                    t.trackerid AS tracker_id,
                    COUNT(*) AS conversions
                FROM
                    {$conf['table']['prefix']}{$conf['table']['trackers']} AS t,
                    {$conf['table']['prefix']}{$conf['table']['data_intermediate_ad_connection']} AS diac
                WHERE
                    t.clientid = $clientid
                    AND t.trackerid = diac.tracker_id
                    AND diac.tracker_date_time >= '" . $currentDate->format('%Y-%m-%d 00:00:00') . "'
                    AND diac.tracker_date_time <= '" . $currentDate->format('%Y-%m-%d 23:59:59') . "'
                    AND diac.connection_type = 1
                    AND diac.connection_status = ". MAX_CONNECTION_STATUS_APPROVED ."
                GROUP BY
                    tracker_id
                ";
            $resTrackerConnections = phpAds_dbQuery($query);
            while ($row = phpAds_dbFetchArray($resTrackerConnections)) {
                $trackers[$row['tracker_id']][$currentDate->format('%Y-%m-%d').'_tracker_click_conversions'] = $row['conversions'];
                $trackers[$row['tracker_id']]['total_tracker_conversions'] += $row['conversions'];
            }
            // Update the current date
            $currentDate = $currentDate->getNextDay();
        }
        
        // Prepare the report
        $report = "Client: ".strip_tags(phpAds_getClientName($clientid))." - ".$start." - ".$end."\n\n";
        // Send the tracker summary column headers
        $report .= $GLOBALS['strID']                      . $delimiter;
        $report .= $GLOBALS['strName']                    . $delimiter;
        $report .= $GLOBALS['strTotalTrackerImpressions'] . $delimiter;
        $report .= $GLOBALS['strTotalTrackerConnections'] . $delimiter;
        $report .= $GLOBALS['strTotalTrackerConversions'] . "\n";
        $report .= "\n";
        // Send the tracker summary data for each tracker
        foreach($trackers as $id => $tracker) {
            $report .= $id                                    . $delimiter;
            $report .= $tracker['name']                       . $delimiter;
            $report .= $tracker['total_tracker_impressions']  . $delimiter;
            $report .= $tracker['total_tracker_connections']  . $delimiter;
            $report .= $tracker['total_tracker_conversions']  . "\n";
        }
        $report .= "\n\n";
        // Send the daily breakdown data for each tracker
        foreach($trackers as $id => $tracker) {
            $report .= $GLOBALS['strID']                      . ':' . $delimiter;
            $report .= $id                                    . "\n";
            $report .= $GLOBALS['strName']                    . ':' . $delimiter;
            $report .= $tracker['name']                       . "\n";
            $report .= $GLOBALS['strDay']                     . $delimiter;
            $report .= $GLOBALS['strTrackerImpressions']      . $delimiter;
            $report .= $GLOBALS['strTrackerImprConnections']  . $delimiter;
            $report .= $GLOBALS['strTrackerClickConnections'] . $delimiter;
            $report .= $GLOBALS['strTrackerImprConversions']  . $delimiter;
            $report .= $GLOBALS['strTrackerClickConversions'] . "\n";
            $currentDate = $startDate;
            for ($counter = 0; $counter <= $days; $counter++) {
                $report .= $currentDate->format('%Y-%m-%d')                                               . $delimiter;
                $report .= $tracker[$currentDate->format('%Y-%m-%d').'_tracker_impressions']              . $delimiter;
                $report .= $tracker[$currentDate->format('%Y-%m-%d').'_tracker_impression_connections']   . $delimiter;
                $report .= $tracker[$currentDate->format('%Y-%m-%d').'_tracker_click_connections']        . $delimiter;
                $report .= $tracker[$currentDate->format('%Y-%m-%d').'_tracker_impression_conversions']   . $delimiter;
                $report .= $tracker[$currentDate->format('%Y-%m-%d').'_tracker_click_conversions']        . "\n";
                // Update the current date
                $currentDate = $currentDate->getNextDay();
            }
            $report .= "\n";
        }
    
        // Send the report
        header('Content-Type: application/csv');
        header('Content-Disposition: inline; filename="trackerhistory.csv"');
        header('Content-Length: ' . strlen($report)); 
        echo $report;
    }

}

?>